#
# spec file for package waf
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           waf
Version:        1.8.14
Release:        2.17
Summary:        A Python-based build system
License:        BSD-3-Clause
Group:          Development/Tools/Building
Url:            https://waf.io
Source0:        https://waf.io/waf-%{version}.tar.bz2
Source1:        https://waf.io/waf-%{version}.tar.bz2.asc
Source2:        %{name}.keyring
Patch0:         waf-1.6.2-libdir.patch
BuildRequires:  fdupes
BuildRequires:  python-devel
Requires:       python
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.

%prep
%setup -q
%patch0

# remove BOM, causes trouble later
sed -i -e '1s/^\xEF\xBB\xBF//' waflib/extras/dpapi.py

%build
extras=
for f in waflib/extras/*.py ; do
  f=$(basename "$f" .py);
  if [ "$f" != "__init__" ]; then
    extras="${extras:+$extras,}$f" ;
  fi
done
./waf-light --make-waf --strip --tools="$extras"

%install
# use waf so it unpacks itself
mkdir _temp ; pushd _temp
cp -av ../waf .
python ./waf >/dev/null 2>&1
pushd .waf-%{version}-*
find . -name '*.py' -printf '%%P\0' |
  xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf/{}
popd
popd

# install the frontend
install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python_version}
ln -s waf-%{python_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
sed -i "1c#!%{_bindir}/python2" %{buildroot}%{_bindir}/waf-%{python_version}

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove duplicates
%fdupes -s %{buildroot}

%files
%defattr(-,root,root,-)
%doc README TODO ChangeLog demos
%{_bindir}/waf
%{_bindir}/waf-%{python_version}
%{_datadir}/waf

%changelog
* Wed Sep 23 2015 mpluskal@suse.com
- Update to 1.8.14
  * Fixed the Visual Studio detection on Python 3 when
  - -msvc_lazy_autodetect is not provided (regression)
  * Enable vala processing on a folder basis with the vala_dir
    parameter - #1601
  * Enable vala resource processing - #1626
  * Minor documentation updates - #1605
- Changes for 1.8.13
  * Exposed the Popen parameters input/timeout to
    cmd_and_log/exec_command (timeout is for Python >= 3.3)
  * Added 'with_sys_path' to Context.load_tool to use/skip
    sys.path
  * Changed gccdeps so that it handle '..' within paths
  * env = conf.env.derive().detach()
  * Changed Sun compiler's default flags from -Kpic to
  - xcode=pic32 - #1625
  * Added bld(rule=, ..., cls_str=, cls_keyword=) for more
    descriptive outputs - #1598
  * Added a lazy Visual Studio detection option
  - -msvc_lazy_autodetect - #1614
  * Changed the definition of function tests to prevent warnings
    with gcc - #1622
* Sat Jul 18 2015 mpluskal@suse.com
- Update to 1.8.12
  * Fixed a regression when building in sub-folders
  * New mac_files attribute which is expected to replace
    mac_resources in waf 1.9 (demos/mac_app/)
  * env = env.derive().detach() to simplify deep copies
* Sat Jul  4 2015 mpluskal@suse.com
- Update project url
- Update to 1.8.11
  * Fortran fixes https://github.com/waf-project/waf/issues/1580
  * Enabled installation of generated .py files
  * Fixed the '--threading' option for valac
  * https://github.com/waf-project/waf/issues/1577
  * Shared library compatibility version handling on OSX
- Changes in 1.8.10
  * Replace cygwin paths in solution files -
  * https://github.com/waf-project/waf/issues/1562
  * Fixed the hcode in why.py -
  * https://github.com/waf-project/waf/issues/1561
  * Enabled execution from any folder:
    "waf configure --top=/arbitrary/folder --out=/tmp/build"
  * Enabled stateless out-of-tree builds by default:
    "waf configure --no-lock-in-top --no-lock-in-run"
  * Fixed the waf file generation on windows in Waf 1.8.9
  * Add OS flags such as LDFLAGS only once -
  * https://github.com/waf-project/waf/issues/1574
  * Fixed conf.multicheck error handling
- Changes in 1.8.9
  * VS 2013 supports cross-compiling for x86 and arm from amd64
  * Perl detection enhancements on Redhat systems
  * More accurate rpath parsing in check_cfg
- Changes in 1.8.8
  * Fixed a regression in Fortran builds #1546
  * Fixed a regression in the libdir installation path on 32-bit
    ubuntu #1552
  * Process -Bstatic and -Bdynamic in parse_flags (pkg-config
    tools)
  * Fortran compiler detection to cover the sxf03 as well as
    the sxf90
  * Jython detection enhancements
  * Doxygen tool enhancements
  * Moved the project to Github/waf.io and updated the
    documentation
* Sat Mar 21 2015 mpluskal@suse.com
- Update to 1.8.7
  * Fixed the default libdir installation suffix on Redhat 64-bit
    systems #1536
  * Fixed the Python 2.6 detection on Redhat systems #1538
  * Enabled gccdeps to work with clang
  * Fixed the detection of clang from the gcc tools
  * Added orig_run_str to help subclasses (do not use Task.hcode)
  * Fixed the detection of older clang compilers versions
  * NEC compiler support
  * Enabled batched_cc.py to work with msvc too
  * Enabled unity.py to process c files
  * Faster dependency calculation in c_dumbpreproc
  * New stracedeps example (cfg blog entry)
  * Added support for xz compression in waf and waf dist
  (Python 3.5)
- Changes in 1.8.6
  * Python file installation fixes
  * Fix for classes containing utf-8 names
  * Hide the progress bar when running waf -ppp
  * Support more header extensions in subst/is_copy
  * Handle non-string and non-list values in substitutions (subst)
  * Show how to track build files timestamps to force partial
    rebuilds (build_file_tracker.py)
  * Added a new extension to detect blender libraries
  * Added extras/prefork.py, extras/preforkunix.py and
    extras/preforkjava.py
  * Updated demos/d
  * Updated demos/vala
  * Updated playground/protobuf
  * Updated playground/cython
  * Updated playground/dynamic_headers
  * Updated playground/netcache
  * Qt5 detection improvements
* Sat Mar 21 2015 mpluskal@suse.com
- Add gpg keyring
- Use fdupes to reduce amount of duplicites
* Fri Jan 30 2015 tchvatal@suse.com
- Version bump to 1.8.5:
  * latest upstream release with various fixes all around
  * Read the ChangeLog file for exhaustive descriptions
- Remove the commented out code that is useless
- Fix shebang on the waf command
- Spec-cleanify
* Mon Apr 21 2014 lars@samba.org
- prepare gpg-offline verification; the pub key is missing from the key servers
- add URLs to source files
- update to 1.7.15
  * Fix for tex.py in python3
  * Optimizations in mem_reducer.py
  * Fixes for the windows console in ansiterm.py
  * Fixes for C++ compilers in gccdeps.py
  * Xcode generator include fixes #1388
  * Fortran scanner improvements #1389
  * Configuration tests with several libraries at once in a string #1390
  * Added support for MSVS 2012 in msvs.py
- update to 1.7.14
  * Fixes for Python 3.3 and 3.4
  * Extra tool for memory reduction some large builds
  * Fix for nasm trailing slashes #1379
  * Fix for eclipse project generators #1377
  * Qt5 tool
  * Handle empty defines when pasting tokens
  * Fix for syms.py on python3 #1361
  * Swig fixes
  * Doxygen recursive dependencies
- update to 1.7.13
  * Fix for library installation on OpenBSD #1355
  * Intel compiler detection fix when using Python3 #1356
- update to 1.7.12
  * Fix for systems without threading #1323
  * Fix for library installation on OpenBSD
  * Propagate the max_depth argument in ant_glob #1328
  * wsdk detection fix #1335
- update to 1.7.11
  * Node.delete remove empty folders #1278
  * Detection of 'convert' in parallel_debug #1300
  * Bibtopic support #1299
  * Safer encoding in ConfigSet dump files #1297
  * Missing Qt defines on Windows #1272
  * QtDesigner library detection #1315
  * Redundant 'check_dir' call causing random uninstall failures #1313
  * Append to moc flags instead of replacing #1317
  * Share moc tasks in the Qt processing #1318
  * Disable a source of unnecessary rebuilds in the Qt processing
  * Use LIB/INCLUDE environment variables in boost library detection on
    windows #1310
  * Reduce the amount of paths in the unit test execution #1319
  * Enabled export_defines/export_includes attribute on read_shlib/read_stlib
* Sat May 11 2013 ecsos@schirra.net
- update to 1.7.10
  * Enhancements in the LaTeX support #1248
  * Codelite plugin by Christian Klein
  * Validate the versioned library number #1180
  * New export_defines keyword for C/C++/Fortran libraries
  * Python config tests enhancements #1231 #1261
  * Enable the distribution of non-python data files #1265
  * Improved the boost configuration output #1266
  * Exclude intltoolcache from waf dist #1267
  * Use Utils.readf/Utils.writef to prevent build cache loss on windows
    platforms
- update to 1.7.9
  * Improved the patch submitted in #1237 as it caused regressions
  * Reverted the patch submitted in #1212 as it caused regressions
  * Added a cache to waflib/extras/gccdeps.py #1244
  * Unit test ut_exec was not obtained properly #1245
- update to 1.7.8
  * Fixed a configuration issue in the visual studio compiler (regression
    [#1239])
- update to 1.7.7
  * XLC and XLF detection fixes #1230
  * Fixed the multiple gcc/msvc builds #1237
  * Better gdc detection on Ubuntu #1222
  * Relative symlinks in symlink_as #1234
  * Various improvements in the doxygen tool #1232 #1233
  * Fixed windows filehandle issues on Python #1235
  * Visual Studio 2012 detection improvements
  * OSX soname installation fix
- update to 1.7.6
  * Better encapsulation of conf.check_cfg(uselib_store=...) defines #1212
  * Support for python modules in fortran
  * Extension files of D binaries on Mac
  * Raise an error when a tex manually-provided dependency is not found #1209
  * Enforce a stable name in bld(rule=..., name=undefined) to prevent rebuilds
  * Enhanced support for flex on win32 and msys #1207 #1211
  * Fixed a regression on configuration tests running with -Werror/-Wall #1220
- update to 1.7.5
  * Fixed the kde4 library detection on Fedora
  * New tool for protocol buffers (protoc.py) #1184
  * Fixed a syntax error affecting Python < 2.6
- update to 1.7.4
  * Fixed a regression in the Node,Task and Context classes
- update to 1.7.3
  * Fixed the LD_LIBRARY_PATH race condition in waf_unit_test #1200
  * Library detection fixes in boost.py #1199
  * Various waf_unit_test enhancements #1194
  * Use the same function signature main(int, char**) in all configuration
    tests #1192
  * Fixed the Clang version number detection #1191
  * Let the feature 'includes' propagate INCLUDES and FRAMEWORKPATH variables
  * Fix for incorrect installation paths #1202
  * Cabal script (haskell)
* Thu Sep  6 2012 vcizek@suse.com
- initial packaging (version 1.7.2)
  * Install bld.subst() targets
  * New scanner for winrc processing #1186
